@@ -12,7 +12,7 @@ from serialzy.utils import cached_installed_packages
 from typing_extensions import get_args, get_origin
 
 from serialzy.api import Serializer, SerializerRegistry, Schema, VersionBoundary
-from serialzy.types import EmptyListContent, get_type
+from serialzy.types import EmptyContent, get_type
 from serialzy.version import __version__
 
 _LOG = logging.getLogger(__name__)
@@ -29,15 +29,14 @@ class SequenceSerializerBase(Serializer, ABC):
         length = len(obj)
         dest.write(length.to_bytes(length=8, byteorder='little', signed=False))
 
-        args = get_args(get_type(obj))
-        serializers = self.__serializers_from_type_args(args)
-
         for i in range(len(obj)):
             with BytesIO() as handle:
-                if len(serializers) == 1:
-                    cast(Serializer, serializers[0]).serialize(obj[i], handle)
-                else:
-                    cast(Serializer, serializers[i]).serialize(obj[i], handle)
+                serializer = cast(Serializer, self._registry.find_serializer_by_type(get_type(obj[i])))
+                data_format = serializer.data_format()
+                handle.write(len(data_format).to_bytes(length=8, byteorder='little', signed=False))
+                handle.write(data_format.encode("utf-8"))
+
+                serializer.serialize(obj[i], handle)
                 handle.flush()
 
                 serialized_value = handle.getvalue()
@@ -49,8 +48,9 @@ class SequenceSerializerBase(Serializer, ABC):
         self._check_types_valid(schema_type, user_type)
 
         length = int.from_bytes(source.read(8), byteorder='little', signed=False)
-        args = get_args(schema_type)
-        serializers = self.__serializers_from_type_args(args)
+        if length == 0:
+            return get_origin(schema_type)([])  # type: ignore
+        # allow list deserialization by both stable and unstable serializers
 
         result = list()
         for i in range(length):
@@ -60,10 +60,10 @@ class SequenceSerializerBase(Serializer, ABC):
                 handle.flush()
                 handle.seek(0)
 
-                if len(serializers) == 1:
-                    obj = cast(Serializer, serializers[0]).deserialize(handle)
-                else:
-                    obj = cast(Serializer, serializers[i]).deserialize(handle)
+                data_format_length = int.from_bytes(handle.read(8), byteorder='little', signed=False)
+                data_format = handle.read(data_format_length).decode("utf-8")
+                serializer = cast(Serializer, self._registry.find_serializer_by_data_format(data_format))
+                obj = serializer.deserialize(handle)
                 result.append(obj)
 
         return get_origin(schema_type)(result)  # type: ignore
@@ -88,7 +88,7 @@ class SequenceSerializerBase(Serializer, ABC):
         return Schema(self.data_format(), self.SCHEMA_FORMAT, json.dumps(schema_dict), self.meta())
 
     def resolve(self, schema: Schema) -> Type:
-        self._validate_schema(schema)
+        # do not check data format here to allow list deserialization by both stable and unstable serializers
         if schema.schema_format != self.SCHEMA_FORMAT:
             raise ValueError(f'Invalid schema format {schema.schema_format}')
 
@@ -140,7 +140,7 @@ class SequenceSerializerStable(SequenceSerializerBase):
     def __check_arg(self, args: Tuple[Any, ...]) -> bool:
         if len(args) == 0:
             return False
-        elif args[0] == EmptyListContent:
+        elif args[0] == EmptyContent:
             return True
 
         for arg in args:
@@ -163,8 +163,8 @@ class SequenceSerializerUnstable(SequenceSerializerBase):
     def __check_arg(self, args: Tuple[Any, ...]) -> bool:
         if len(args) == 0:
             return False
-        elif args[0] == EmptyListContent:
-            return False
+        elif args[0] == EmptyContent:
+            return True
 
         for arg in args:
             serializer = self._registry.find_serializer_by_type(arg)
